#!/bin/bash

#Set the username used for web access to the router
ROUTER_USER="root"
#Set the password used for web access to the router
ROUTER_PWD="admin"
#Set the IP address where the router can be reached, optional port
#number can be specified like 192.168.1.1:80
ROUTER_IP="192.168.1.1"

#If you have your router setup to support https, change to https
PROTO="http"

LOGS="/var/log/wifi/"

read_macs () {
	while read line
	do
		if [ "${line//active_wireless/}" != "$line" ]; then
			OFS="$IFS"
			IFS="\'"
			for word in ${line[@]}
			do
				if [ "${#word}" -eq "17" ]; then
				mac="${word//:/}"
					if [ "${#mac}" -eq "12" ]; then
						echo "$mac"
					fi
				fi
			done
			OFS="$IFS"
			mac=""
			word=""
		fi
	done
}

read_ssid () {
        while read line
        do
                if [ "${line//wl_ssid/}" != "$line" ]; then
			line="${line##*"wl_ssid::"}"
			line="${line%%"}"*}"
			echo "$line"
                fi
        done
}

read_company () {
        while read line
        do
                if [ "${line//"(base 16)"/}" != "$line" ]; then
                        line="${line##*'(base 16)'}"
                        line="${line:2}"
                        echo "$line"
                fi
        done
}


if ! [ -d "$LOGS" ]; then
	echo "Logs directory $LOGS does not exist" >&2
	exit 1
fi

wldata="`curl -s --user $ROUTER_USER:$ROUTER_PWD $PROTO://$ROUTER_IP/Status_Wireless.live.asp`"
ssid="`echo $wldata |read_ssid`"
macs=(`echo $wldata |read_macs`)

for mac in ${macs[@]}
do
	if ! [ -f "$LOGS/$mac" ]; then
		company="`curl -s "http://standards.ieee.org/cgi-bin/ouisearch?${mac:0:6}" |read_company`"
		echo "Alert new client found on $ssid MAC: $mac ($company)"
		echo "New MAC Address detected: `date`" >>$LOGS/$mac
		echo -e "${mac:0:6}\t\t$company" >>$LOGS/$mac
		echo -e "Additional Data:\n$wldata" >>$LOGS/$mac
	fi
done

